soam package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   soam.core
   soam.models
   soam.plotting
   soam.reporting
   soam.savers
   soam.utilities
   soam.workflow

Submodules
----------

soam.cfg module
---------------

.. automodule:: soam.cfg
   :members:
   :undoc-members:
   :show-inheritance:

soam.constants module
---------------------

.. automodule:: soam.constants
   :members:
   :undoc-members:
   :show-inheritance:

soam.data\_models module
------------------------

.. automodule:: soam.data_models
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: soam
   :members:
   :undoc-members:
   :show-inheritance:
